********************************************************************************
*** PURPOSE: Create figures and tables in main paper		         		 ***
*** AUTHORS: Ines Lee and Eileen Tipoe										 ***
*** DATE LAST UPDATED: 2021-08-31											 ***
********************************************************************************

/*** DIRECTORIES (PLS UPDATE ROOT PATH BEFORE RUNNING CODE) ***/
global root = "XXXX" 
global output = "$root/Output"

/*----------------------------------------------------------------------------
FIGURE 1
------------------------------------------------------------------------------*/

use "$root/Data/panel_long_rep.dta", clear

/*** GRAPHS ***/
foreach var in "employmentwd_main" "housework_main" "leisure_main" "subsistence_main" {

local group1 = "g_fem"
local group2 = "g_u11"

if "`var'" == "employmentwd_main" {
	local pos1 = "lb"
	local pos2 = "s"
	local title = "(A) Change in hours spent on employment as main activity"

}

if "`var'" == "housework_main" {
	local pos1 = "ub"
	local pos2 = "n"
	local activity = "housework"
	local title = "(B) Change in hours spent on housework as main activity"

}

if "`var'" == "leisure_main" {
	local pos1 = "ub"
	local pos2 = "n"
	local activity = "leisure"
	local title = "(C) Change in hours spent on leisure as main activity"

}

if "`var'" == "subsistence_main" {
	local pos1 = "ub"
	local pos2 = "n"
	local activity = "subsistence"
	local title = "(D) Change in hours spent on subsistence as main activity"
}

foreach period in 1 2 3 {
qui ci means d_`var' if period==`period' & `group1'==1 
local `group1'_1_`period'_m: display %9.2f r(mean) 
local `group1'_1_`period'_ub: display %9.2f r(ub) 
local `group1'_1_`period'_lb: display %9.2f r(lb)

qui ci means d_`var' if period==`period' & `group1'==2 
local `group1'_2_`period'_m: display %9.2f r(mean)
local `group1'_2_`period'_ub: display %9.2f r(ub)
local `group1'_2_`period'_lb: display %9.2f r(lb)

qui ci means d_`var' if period==`period' & `group2'==1 
local `group2'_1_`period'_m: display %9.2f r(mean)
local `group2'_1_`period'_ub: display %9.2f r(ub)
local `group2'_1_`period'_lb: display %9.2f r(lb)

qui ci means d_`var' if period==`period' & `group2'==2 
local `group2'_2_`period'_m: display %9.2f r(mean)
local `group2'_2_`period'_ub: display %9.2f r(ub)
local `group2'_2_`period'_lb: display %9.2f r(lb)
}

foreach period in 1 2 3 {
qui su ts_`var'  if period==`period' & `group1'==1 
local `group1'_1_`period': display %9.2f r(mean)
qui su ts_`var'  if period==`period' & `group1'==2 
local `group1'_2_`period': display %9.2f r(mean)

qui su ts_`var'  if period==`period' & `group2'==1 
local `group2'_1_`period': display %9.2f r(mean)
qui su ts_`var'  if period==`period' & `group2'==2 
local `group2'_2_`period': display %9.2f r(mean)
}

qui mean d_`var' if period==1, over(`group1') 
est sto p1
qui mean d_`var' if period==2, over(`group1')  
est sto p2

qui mean d_`var' if period==1, over(`group2') 
est sto p1a
qui mean d_`var' if period==2, over(`group2')  
est sto p2a

coefplot (p1, recast(bar) barwidth(0.3) fcolor(none) lcolor(black) offset(-0.15)) ///
		 (p1, ms(i) offset(-0.15)) ///
		 (p2, recast(bar) barwidth(0.3) fcolor(*.5) fcolor(gs13) lcolor(black)  offset(0.15)) ///
		 (p2, ms(i) offset(0.15)) ///
		 (p1a, recast(bar) barwidth(0.3) fcolor(none) lcolor(black) offset(-0.15)) ///
		 (p1a, ms(i) offset(-0.15)) ///
		 (p2a, recast(bar) barwidth(0.3) fcolor(*.5) fcolor(gs13) lcolor(black)  offset(0.15)) ///
		 (p2a, ms(i) offset(0.15)), ///
		 vertical ciopts(recast(rcap) lwidth(thin) lcolor(black)) ///
		 coeflabels(c.d_`var'@1.g_fem="Male" c.d_`var'@2.g_fem="Female" c.d_`var'@1.g_u11="No child under 11" c.d_`var'@2.g_u11="Child under 11" , notick labgap(1) labsize(small)) ///
		 title("`title'", size(medium)) ///
		 text(``group1'_1_1_`pos1'' 0.80 "``group1'_1_1_m'", size(small) place(`pos2')) ///
		 text(``group1'_1_2_`pos1'' 1.10 "``group1'_1_2_m'", size(small) place(`pos2')) ///
		 text(``group1'_2_1_`pos1'' 1.80 "``group1'_2_1_m'", size(small) place(`pos2')) ///
		 text(``group1'_2_2_`pos1'' 2.10 "``group1'_2_2_m'", size(small) place(`pos2')) ///
		 text(``group2'_1_1_`pos1'' 2.80 "``group2'_1_1_m'", size(small) place(`pos2')) ///
		 text(``group2'_1_2_`pos1'' 3.10 "``group2'_1_2_m'", size(small) place(`pos2')) ///
		 text(``group2'_2_1_`pos1'' 3.80 "``group2'_2_1_m'", size(small) place(`pos2')) ///
		 text(``group2'_2_2_`pos1'' 4.10 "``group2'_2_2_m'", size(small) place(`pos2')) ///
		 text(-1.5 0.8 "{it:Pre:}", size(small) place(e)) ///
		 text(-1.7 0.8 "{it:LD 1:}", size(small) place(e)) ///
		 text(-1.9 0.8 "{it:LD 3:}", size(small) place(e)) ///
		 text(-1.5 1.8 "{it:Pre:}", size(small) place(e)) ///
		 text(-1.7 1.8 "{it:LD 1:}", size(small) place(e)) ///
		 text(-1.9 1.8 "{it:LD 3:}", size(small) place(e)) ///
		 text(-1.5 2.8 "{it:Pre:}", size(small) place(e)) ///
		 text(-1.7 2.8 "{it:LD 1:}", size(small) place(e)) ///
		 text(-1.9 2.8 "{it:LD 3:}", size(small) place(e)) ///
		 text(-1.5 3.8 "{it:Pre:}", size(small) place(e)) ///
		 text(-1.7 3.8 "{it:LD 1:}", size(small) place(e)) ///
		 text(-1.9 3.8 "{it:LD 3:}", size(small) place(e)) ///
		 text(-1.5 1.0 "``group1'_1_1'", size(small) place(e)) ///
		 text(-1.7 1.0 "``group1'_1_2'", size(small) place(e)) ///
		 text(-1.9 1.0 "``group1'_1_3'", size(small) place(e)) ///
		 text(-1.5 2.0 "``group1'_2_1'", size(small) place(e)) ///
		 text(-1.7 2.0 "``group1'_2_2'", size(small) place(e)) ///
		 text(-1.9 2.0 "``group1'_2_3'", size(small) place(e)) ///
		 text(-1.5 3.0 "``group2'_1_1'", size(small) place(e)) ///
		 text(-1.7 3.0 "``group2'_1_2'", size(small) place(e)) ///
		 text(-1.9 3.0 "``group2'_1_3'", size(small) place(e)) ///
		 text(-1.5 4.0 "``group2'_2_1'", size(small) place(e)) ///
		 text(-1.7 4.0 "``group2'_2_2'", size(small) place(e)) ///
		 text(-1.9 4.0 "``group2'_2_3'", size(small) place(e)) ///
		 format(%9.2f) plotregion(margin(b=0)) ///
		 yline(0, lcolor(red)) ///
		 ylabel(-2(0.5)1.5, format(%3.1f) labsize(small)) yscale(range(-2(0.5)1.5)) ///
		 graphregion(color(white)) ///
		 legend(order (2 "Lockdown 1 (LD1) vs. Pre" 6 "Lockdown 3 (LD3)  vs. Pre") col(2) size(vsmall) symxsize(*0.25) bmargin(zero))
	 	
graph save Graph "$output/barchart_`var'.gph", replace
}

grc1leg "$output/barchart_employmentwd_main.gph" ///
		"$output/barchart_housework_main.gph" ///
		"$output/barchart_leisure_main.gph" ///
		"$output/barchart_subsistence_main.gph", ///
		imargin(vsmall) scheme(s1color) commonscheme iscale(*0.80) graphregion(margin(vsmall)) legendfrom("$output/barchart_employmentwd_main.gph") xsize(10) col(2)
		
graph export "$output/Figure1.tif", as(tif) width(3000) replace

erase "$output/barchart_employmentwd_main.gph"
erase "$output/barchart_housework_main.gph"
erase "$output/barchart_leisure_main.gph"
erase "$output/barchart_subsistence_main.gph"

/*----------------------------------------------------------------------------
FIGURE 2 
------------------------------------------------------------------------------*/

use "$root/Data/panel_wide_rep.dta", clear

global controls = "BA_above age_25_29 age_30_34 age_35_39 age_40_44 age_45_49 age_50_54 age_55_59 age_60 i.white income_1k_2k income_2k_3k income_3k_4k income_4k_5k income_5k"

/*** Results: Employment Heckman Corrected ***/

* Heckman selection model LD1 
bootstrap, reps(1000) seed(12345): heckman ts_employmentwd_main_LD1 i.female##i.lw_child_u11 c.ts_employmentwd_main_pre $controls wfh_ld1, select(prev_wfh i.female##i.lw_child_u11 $controls working_pre) twostep 

est sto heck_employmentwd_main1
	
* Heckman selection model LD3 
bootstrap, reps(1000) seed(12345): heckman ts_employmentwd_main_LD3 i.female##i.lw_child_u11 c.ts_employmentwd_main_pre $controls wfh_ld3, select(prev_wfh i.female##i.lw_child_u11 $controls working_pre) twostep 
	
est sto heck_employmentwd_main2

/*** Results: Other outcomes (non-heckman selected) ***/

foreach var in housework_main leisure_main subsistence_main {
	
	qui reg ts_`var'_LD1 i.female##i.lw_child_u11 c.ts_`var'_pre $controls wfh_ld1, r 

	est sto `var'1
	
	qui reg ts_`var'_LD3 i.female##i.lw_child_u11 c.ts_`var'_pre $controls wfh_ld3, r 
	
	est sto `var'2

}

/*** Graph ***/
global keep = "1.female  1.lw_child_u11 1.female#1.lw_child_u11 1.white income_1k_2k income_2k_3k income_3k_4k income_4k_5k income_5k"
global coeflabels = `" 1.female="Female"  1.lw_child_u11="Has child under 11" 1.female#1.lw_child_u11="Female X Has child under 11" 1.white="White" income_1k_2k="Income 1-2k" income_2k_3k="Income 2-3k" income_3k_4k="Income 3-4k" income_4k_5k="Income 4-5k" income_5k="Income >=5k""'

coefplot (heck_employmentwd_main1, offset(0.2) msymbol(C)  mlabposition(10)) ///
		 (heck_employmentwd_main2, offset(-0.2) msymbol(D) mlabposition(10)), bylabel("(A) Employment")  || ///
		 (housework_main1) (housework_main2), bylabel("(B) Housework") || ///
		 (leisure_main1) (leisure_main2), bylabel("(C) Leisure") || ///
		 (subsistence_main1) (subsistence_main2), bylabel("(D) Subsistence") || ///
		 ,  keep($keep) coeflabels($coeflabels , wrap(14) noticks labsize(small)) xline(0, lpattern(dash) lcolor(gs12) lwidth(thin)) mlabsize(small) mlabgap(*0.5) mfcolor(white) xscale(range(-3 3)) xlabel(-3(1)3,format(%2.0f) labsize(vsmall)) mlabel(cond(@pval<.01, string(@b,"%9.2f")+"***", cond(@pval<.05, string(@b,"%9.2f")+"**", cond(@pval<.1, string(@b,"%9.2f")+"*", string(@b,"%9.2f"))))) legend(order(2 "Lockdown 1" 4 "Lockdown 3") position(6) ring(0) row(1) bplacement(neast) symxsize(*0.5) size(vsmall) region(lwidth(none))) byopts(compact cols(4) graphregion(color(white) margin(tiny))) subtitle(, size(medsmall) margin(vsmall) bcolor(white)) 
		 
graph export "$output/Figure2.tif", as(tif) width(3000) replace

/*** --------------------------------------------------------------------------- 
FIGURE 3 
--------------------------------------------------------------------------- ***/

use "$root/Data/panel_long_rep.dta", clear

g d_p_unusual_workhrs = d_unusual_workhrs_ts > 0 if !mi(d_unusual_workhrs_ts)
g d_p_unusual_housework = d_unusual_housework_ts > 0 if !mi(d_unusual_housework_ts)
g q_p_unusual_workhrs = q_unusual_workhrs_ts > 0 if !mi(q_unusual_workhrs_ts)
g q_p_unusual_housework = q_unusual_housework_ts > 0 if !mi(q_unusual_housework_ts)

foreach var in multitasking_cross_ts leisure_alone_ts p_unusual_workhrs p_unusual_housework {

if "`var'" == "multitasking_cross_ts" | "`var'" == "leisure_alone_ts" { 
g q_`var'0 = .
replace q_`var'0 = q_`var'
}


if "`var'" == "p_unusual_workhrs" | "`var'" == "p_unusual_housework" { 
g d_`var'_hrs = .
replace d_`var' = d_`var'*100
g q_`var'0 = .
replace q_`var'0 = q_`var'*100
}


if "`var'" == "multitasking_cross_ts" {
	local pos1a = "ub"
	local pos2a = "n"
	local pos1b = "lb"
	local pos2b = "s"
	local ymin = -3 
	local ymax = 3
	local int = 1
	local labposy1 = `ymin' + 0.85*`int'
	local labposy2 = `labposy1' - 0.3*`int'
	local labposy3 = `labposy2' - 0.3*`int'
	local title = "(A) Change in hours spent multitasking"
	local fmt = "%3.0f"
}

if "`var'" == "leisure_alone_ts" {
	local pos1a = "ub"
	local pos2a = "n"
	local pos1b = "ub"
	local pos2b = "n"
	local ymin = -3 
	local ymax = 3
	local int = 1
	local labposy1 = `ymin' + 0.85*`int'
	local labposy2 = `labposy1' - 0.3*`int'
	local labposy3 = `labposy2' - 0.3*`int'
	local title = "(B) Change in hours spent alone on leisure activities"
	local fmt = "%3.0f"
}

if "`var'" == "p_unusual_workhrs" {
	local pos1a = "ub"
	local pos2a = "n"
	local pos1b = "ub"
	local pos2b = "n"
	local ymin = -10 
	local ymax = 50
	local int = 10
	local labposy1 = `ymin' + 0.85*`int'
	local labposy2 = `labposy1' - 0.3*`int'
	local labposy3 = `labposy2' - 0.3*`int'
	local title = "(C) % Individuals who increased unusual work hours"
	local fmt = "%3.0f"
}

if "`var'" == "p_unusual_housework" {
	local pos1a = "ub"
	local pos2a = "n"
	local pos1b = "ub"
	local pos2b = "n"
	local ymin = -10 
	local ymax = 50
	local int = 10
	local labposy1 = `ymin' + 0.85*`int'
	local labposy2 = `labposy1' - 0.3*`int'
	local labposy3 = `labposy2' - 0.3*`int'
	local title = "(D) % Individuals who increased unusual housework hours"
	local fmt = "%3.0f"
}

local group1 = "g_fem"
local group2 = "g_u11"

mean d_`var' if period==1, over(`group1') 
est sto p1
mean d_`var' if period==2, over(`group1')  
est sto p2
mean d_`var' if period==3, over(`group1')  
est sto p3

mean d_`var' if period==1, over(`group2') 
est sto p1a
mean d_`var' if period==2, over(`group2')  
est sto p2a
mean d_`var' if period==3, over(`group2')  
est sto p3a

foreach period in 1 2 3 {
ci means d_`var' if period==`period' & `group1'==1 
local `group1'_1_`period'_m: display %9.2f r(mean)
local `group1'_1_`period'_ub: display %9.2f r(ub)
local `group1'_1_`period'_lb: display %9.2f r(lb)

ci means d_`var' if period==`period' & `group1'==2 
local `group1'_2_`period'_m: display %9.2f r(mean)
local `group1'_2_`period'_ub: display %9.2f r(ub)
local `group1'_2_`period'_lb: display %9.2f r(lb)

ci means d_`var' if period==`period' & `group2'==1 
local `group2'_1_`period'_m: display %9.2f r(mean)
local `group2'_1_`period'_ub: display %9.2f r(ub)
local `group2'_1_`period'_lb: display %9.2f r(lb)

ci means d_`var' if period==`period' & `group2'==2 
local `group2'_2_`period'_m: display %9.2f r(mean)
local `group2'_2_`period'_ub: display %9.2f r(ub)
local `group2'_2_`period'_lb: display %9.2f r(lb)
}


foreach period in 1 2 3 {
qui su q_`var'0  if period==`period' & `group1'==1 
local `group1'_1_`period': display %9.2f r(mean)
qui su q_`var'0  if period==`period' & `group1'==2 
local `group1'_2_`period': display %9.2f r(mean)

qui su q_`var'0  if period==`period' & `group2'==1 
local `group2'_1_`period': display %9.2f r(mean)
qui su q_`var'0  if period==`period' & `group2'==2 
local `group2'_2_`period': display %9.2f r(mean)
}

coefplot (p1, recast(bar) barwidth(0.3) fcolor(none) lcolor(black) offset(-0.15)) ///
		 (p1, ms(i) offset(-0.15)) ///
		 (p2, recast(bar) barwidth(0.3) fcolor(*.5) fcolor(gs13) lcolor(black)  offset(0.15)) ///
		 (p2, ms(i) offset(0.15)) ///
		 (p1a, recast(bar) barwidth(0.3) fcolor(none) lcolor(black) offset(-0.15)) ///
		 (p1a, ms(i) offset(-0.15)) ///
		 (p2a, recast(bar) barwidth(0.3) fcolor(*.5) fcolor(gs13) lcolor(black)  offset(0.15)) ///
		 (p2a, ms(i) offset(0.15)), ///
		 vertical ciopts(recast(rcap) lwidth(vthin) lcolor(black)) ///
		 coeflabels(c.d_`var'@1.g_fem="Male" c.d_`var'@2.g_fem="Female" c.d_`var'@1.g_u11="No child under 11" c.d_`var'@2.g_u11="Child under 11" , notick labgap(1) labsize(small)) ///
		 title("`title'", size(medium)) ///
		 text(``group1'_1_1_`pos1a'' 0.80 "``group1'_1_1_m'", size(small) place(`pos2a')) ///
		 text(``group1'_1_2_`pos1b'' 1.10 "``group1'_1_2_m'", size(small) place(`pos2b')) ///
		 text(``group1'_2_1_`pos1a'' 1.80 "``group1'_2_1_m'", size(small) place(`pos2a')) ///
		 text(``group1'_2_2_`pos1b'' 2.10 "``group1'_2_2_m'", size(small) place(`pos2b')) ///
		 text(``group2'_1_1_`pos1a'' 2.80 "``group2'_1_1_m'", size(small) place(`pos2a')) ///
		 text(``group2'_1_2_`pos1b'' 3.10 "``group2'_1_2_m'", size(small) place(`pos2b')) ///
		 text(``group2'_2_1_`pos1a'' 3.80 "``group2'_2_1_m'", size(small) place(`pos2a')) ///
		 text(``group2'_2_2_`pos1b'' 4.10 "``group2'_2_2_m'", size(small) place(`pos2b')) ///
		 text(`labposy1' 0.8 "{it:Pre:}", size(small) place(e)) ///
		 text(`labposy2' 0.8 "{it:LD 1:}", size(small) place(e)) ///
		 text(`labposy3' 0.8 "{it:LD 3:}", size(small) place(e)) ///
		 text(`labposy1' 1.8 "{it:Pre:}", size(small) place(e)) ///
		 text(`labposy2' 1.8 "{it:LD 1:}", size(small) place(e)) ///
		 text(`labposy3' 1.8 "{it:LD 3:}", size(small) place(e)) ///
		 text(`labposy1' 2.8 "{it:Pre:}", size(small) place(e)) ///
		 text(`labposy2' 2.8 "{it:LD 1:}", size(small) place(e)) ///
		 text(`labposy3' 2.8 "{it:LD 3:}", size(small) place(e)) ///
		 text(`labposy1' 3.8 "{it:Pre:}", size(small) place(e)) ///
		 text(`labposy2' 3.8 "{it:LD 1:}", size(small) place(e)) ///
		 text(`labposy3' 3.8 "{it:LD 3:}", size(small) place(e)) ///
		 text(`labposy1' 1.0 "``group1'_1_1'", size(small) place(e)) ///
		 text(`labposy2' 1.0 "``group1'_1_2'", size(small) place(e)) ///
		 text(`labposy3' 1.0 "``group1'_1_3'", size(small) place(e)) ///
		 text(`labposy1' 2.0 "``group1'_2_1'", size(small) place(e)) ///
		 text(`labposy2' 2.0 "``group1'_2_2'", size(small) place(e)) ///
		 text(`labposy3' 2.0 "``group1'_2_3'", size(small) place(e)) ///
		 text(`labposy1' 3.0 "``group2'_1_1'", size(small) place(e)) ///
		 text(`labposy2' 3.0 "``group2'_1_2'", size(small) place(e)) ///
		 text(`labposy3' 3.0 "``group2'_1_3'", size(small) place(e)) ///
		 text(`labposy1' 4.0 "``group2'_2_1'", size(small) place(e)) ///
		 text(`labposy2' 4.0 "``group2'_2_2'", size(small) place(e)) ///
		 text(`labposy3' 4.0 "``group2'_2_3'", size(small) place(e)) ///
		format(%9.2f) plotregion(margin(b=0)) ///
		yline(0, lcolor(red)) ///
		graphregion(color(white)) ///
		ylabel(`ymin'(`int')`ymax', format(`fmt') labsize(small)) yscale(range(`ymin' `ymax')) ///
		legend(order (2 "Lockdown 1 (LD1) vs. Pre" 6 "Lockdown 3 (LD3)  vs. Pre") col(2) size(vsmall) symxsize(*0.25) bmargin(zero))
	 	
graph save Graph "$output/barchart_`var'.gph", replace
}

grc1leg "$output/barchart_multitasking_cross_ts.gph" ///
		"$output/barchart_leisure_alone_ts.gph" ///
		"$output/barchart_p_unusual_workhrs.gph" ///
		"$output/barchart_p_unusual_housework.gph", ///
		imargin(vsmall) scheme(s1color) commonscheme iscale(*0.80) graphregion(margin(vsmall)) legendfrom("$output/barchart_multitasking_cross_ts.gph") xsize(10) col(2)

graph export "$output/Figure3.tif", as(tif) width(3000) replace
		
erase "$output/barchart_multitasking_cross_ts.gph"
erase "$output/barchart_leisure_alone_ts.gph" 
erase "$output/barchart_p_unusual_workhrs.gph"
erase "$output/barchart_p_unusual_housework.gph"


/*** --------------------------------------------------------------------------- 
FIGURE 4 
--------------------------------------------------------------------------- ***/

use "$root/Data/panel_long_rep.dta", clear

local group1 = "g_fem"
local group2 = "g_u11"

local pos1 = "lb"
local pos2 = "s"

foreach period in 1 2 3 {
ci means d_enjoyment_wt if period==`period' & `group1'==1 
local `group1'_1_`period'_m: display %9.2f r(mean)
local `group1'_1_`period'_ub: display %9.2f r(ub)
local `group1'_1_`period'_lb: display %9.2f r(lb)

ci means d_enjoyment_wt if period==`period' & `group1'==2 
local `group1'_2_`period'_m: display %9.2f r(mean)
local `group1'_2_`period'_ub: display %9.2f r(ub)
local `group1'_2_`period'_lb: display %9.2f r(lb)

ci means d_enjoyment_wt if period==`period' & `group2'==1 
local `group2'_1_`period'_m: display %9.2f r(mean)
local `group2'_1_`period'_ub: display %9.2f r(ub)
local `group2'_1_`period'_lb: display %9.2f r(lb)

ci means d_enjoyment_wt if period==`period' & `group2'==2 
local `group2'_2_`period'_m: display %9.2f r(mean)
local `group2'_2_`period'_ub: display %9.2f r(ub)
local `group2'_2_`period'_lb: display %9.2f r(lb)
}

foreach period in 1 2 3 {
qui su enjoyment_wt  if period==`period' & `group1'==1 
local `group1'_1_`period': display %9.2f r(mean)
qui su enjoyment_wt  if period==`period' & `group1'==2 
local `group1'_2_`period': display %9.2f r(mean)

qui su enjoyment_wt  if period==`period' & `group2'==1 
local `group2'_1_`period': display %9.2f r(mean)
qui su enjoyment_wt  if period==`period' & `group2'==2 
local `group2'_2_`period': display %9.2f r(mean)
}

mean d_enjoyment_wt if period==1, over(`group1') 
est sto p1
mean d_enjoyment_wt if period==2, over(`group1')  
est sto p2

mean d_enjoyment_wt if period==1, over(`group2') 
est sto p1a
mean d_enjoyment_wt if period==2, over(`group2')  
est sto p2a

coefplot (p1, recast(bar) barwidth(0.2) fcolor(none) lcolor(black) offset(-0.1)) ///
		 (p1, ms(i) offset(-0.1)) ///
		 (p2, recast(bar) barwidth(0.2) fcolor(*.5) fcolor(gs13) lcolor(black)  offset(0.1)) ///
		 (p2, ms(i) offset(0.1)) ///
		 (p1a, recast(bar) barwidth(0.2) fcolor(none) lcolor(black) offset(-0.1)) ///
		 (p1a, ms(i) offset(-0.1)) ///
		 (p2a, recast(bar) barwidth(0.2) fcolor(*.5) fcolor(gs13) lcolor(black)  offset(0.1)) ///
		 (p2a, ms(i) offset(0.1)), ///
		 vertical ciopts(recast(rcap) lwidth(thin) lcolor(black)) ///
		 coeflabels(c.d_enjoyment_wt@1.g_fem="Male" c.d_enjoyment_wt@2.g_fem="Female" c.d_enjoyment_wt@1.g_u11="No child under 11" c.d_enjoyment_wt@2.g_u11="Child under 11" , notick labgap(1) labsize(small)) ///
		 title("Changes in reported enjoyment levels") ///
		 text(``group1'_1_1_`pos1'' 0.85 "``group1'_1_1_m'", size(small) place(`pos2')) ///
		 text(``group1'_1_2_`pos1'' 1.05 "``group1'_1_2_m'", size(small) place(`pos2')) ///
		 text(``group1'_2_1_`pos1'' 1.85 "``group1'_2_1_m'", size(small) place(`pos2')) ///
		 text(``group1'_2_2_`pos1'' 2.05 "``group1'_2_2_m'", size(small) place(`pos2')) ///
		 text(``group2'_1_1_`pos1'' 2.85 "``group2'_1_1_m'", size(small) place(`pos2')) ///
		 text(``group2'_1_2_`pos1'' 3.05 "``group2'_1_2_m'", size(small) place(`pos2')) ///
		 text(``group2'_2_1_`pos1'' 3.85 "``group2'_2_1_m'", size(small) place(`pos2')) ///
		 text(``group2'_2_2_`pos1'' 4.05 "``group2'_2_2_m'", size(small) place(`pos2')) ///
		 text(-0.7 0.8 "{it:Pre:}", size(small) place(e)) ///
		 text(-0.8 0.8 "{it:LD 1:}", size(small) place(e)) ///
		 text(-0.9 0.8 "{it:LD 3:}", size(small) place(e)) ///
		 text(-0.7 1.8 "{it:Pre:}", size(small) place(e)) ///
		 text(-0.8 1.8 "{it:LD 1:}", size(small) place(e)) ///
		 text(-0.9 1.8 "{it:LD 3:}", size(small) place(e)) ///
		 text(-0.7 2.8 "{it:Pre:}", size(small) place(e)) ///
		 text(-0.8 2.8 "{it:LD 1:}", size(small) place(e)) ///
		 text(-0.9 2.8 "{it:LD 3:}", size(small) place(e)) ///
		 text(-0.7 3.8 "{it:Pre:}", size(small) place(e)) ///
		 text(-0.8 3.8 "{it:LD 1:}", size(small) place(e)) ///
		 text(-0.9 3.8 "{it:LD 3:}", size(small) place(e)) ///
		 text(-0.7 1.0 "``group1'_1_1'", size(small) place(e)) ///
		 text(-0.8 1.0 "``group1'_1_2'", size(small) place(e)) ///
		 text(-0.9 1.0 "``group1'_1_3'", size(small) place(e)) ///
		 text(-0.7 2.0 "``group1'_2_1'", size(small) place(e)) ///
		 text(-0.8 2.0 "``group1'_2_2'", size(small) place(e)) ///
		 text(-0.9 2.0 "``group1'_2_3'", size(small) place(e)) ///
		 text(-0.7 3.0 "``group2'_1_1'", size(small) place(e)) ///
		 text(-0.8 3.0 "``group2'_1_2'", size(small) place(e)) ///
		 text(-0.9 3.0 "``group2'_1_3'", size(small) place(e)) ///
		 text(-0.7 4.0 "``group2'_2_1'", size(small) place(e)) ///
		 text(-0.8 4.0 "``group2'_2_2'", size(small) place(e)) ///
		 text(-0.9 4.0 "``group2'_2_3'", size(small) place(e)) ///
		 format(%9.2f) plotregion(margin(b=0)) ///
		 yline(0, lcolor(red)) ///
		 graphregion(color(white)) ///
		 ylabel(-1.0(0.5)0.5, format(%3.1f) labsize(small)) yscale(range(-1.0 0.5)) ///
		 legend(order (2 "Lockdown 1 (LD1) vs. Pre" 6 "Lockdown 3 (LD3)  vs. Pre") col(2) size(small) symxsize(*0.25) margin(vsmall) position(6) ring(0) row(1) bplacement(north) region(lwidth(none))) 
	 	
graph export "$output/Figure4.tif", as(tif) width(3000) replace

/*----------------------------------------------------------------------------
FIGURE 5
------------------------------------------------------------------------------*/
use "$root/Data/panel_wide_rep.dta", clear

global controls = "i.female##i.lw_child_u11 BA_above age_25_29 age_30_34 age_35_39 age_40_44 age_45_49 age_50_54 age_55_59 age_60 white income_1k_2k income_2k_3k income_3k_4k income_4k_5k income_5k"

global miss_num -999

*** PRE VS LD1 ***

* Changes in quantity variables
foreach var in housework_main employmentwd_main leisure_main subsistence_main {
	cap drop D`var'
	g D`var' = d_`var'_preLD1 
}

* Changes in quality variables
cap drop *_inc_*
foreach p in preLD1 {

g strange_workhrs_inc_`p' = d_unusual_workhrs_ts_`p' 
g strange_housework_inc_`p' = d_unusual_housework_ts_`p'   
g multitasking_inc_`p' = d_multitasking_cross_ts_`p' 
g alone_inc_`p' = d_leisure_alone_ts_`p' 
}

foreach var in strange_workhrs_inc strange_housework_inc multitasking_inc alone_inc {
	cap drop D`var'
	g D`var' = `var'_preLD1
}

* Deal with missings 
cap drop emp_missing
g emp_missing = Demploymentwd_main == .
replace Demploymentwd_main = $miss_num if emp_missing==1

reg d_enjoyment_wt_preLD1 Dhousework_main Demploymentwd_main Dleisure_main Dsubsistence_main Dmultitasking_inc Dalone_inc Dstrange_workhrs_inc Dstrange_housework_inc $controls wfh_ld1 emp_missing, r

est sto enjoy_LD1

*** PRE VS LD3 ***

* Changes in quantity variables

foreach var in housework_main employmentwd_main leisure_main subsistence_main {
	cap drop D`var'
	g D`var' = d_`var'_preLD3 
}

* Changes in quanlity variables
cap drop *_inc_*
foreach p in preLD3 {

gen strange_workhrs_inc_`p' = d_unusual_workhrs_ts_`p' 
gen strange_housework_inc_`p' = d_unusual_housework_ts_`p'   
gen multitasking_inc_`p' = d_multitasking_cross_ts_`p' 
gen alone_inc_`p' = d_leisure_alone_ts_`p' 
}

foreach var in strange_workhrs_inc strange_housework_inc multitasking_inc alone_inc {
	cap drop D`var'
	g D`var' = `var'_preLD3
}

* Deal with missings 
cap drop emp_missing
g emp_missing = Demploymentwd_main == .
replace Demploymentwd_main = $miss_num if emp_missing==1

reg d_enjoyment_wt_preLD3 Dhousework_main Demploymentwd_main Dleisure_main Dsubsistence_main Dmultitasking_inc Dalone_inc Dstrange_workhrs_inc Dstrange_housework_inc $controls wfh_ld3 emp_missing, r

est sto enjoy_LD3

/*** GRAPH ***/
global keep = "Dhousework_main Demploymentwd_main Dleisure_main Dsubsistence_main Dmultitasking_inc Dalone_inc Dstrange_workhrs_inc Dstrange_housework_inc "
global coeflabels = `" Dhousework_main="Housework" Demploymentwd_main="Employment" Dleisure_main="Leisure" Dsubsistence_main="Subsistence" Dmultitasking_inc="Multitasking" Dalone_inc="Leisure alone" Dstrange_workhrs_inc="Unusual work hours" Dstrange_housework_inc="Unusual housework hours" "'
		 
coefplot (enjoy_LD1, offset(0.2) msymbol(C)  mlabposition(2)) ///
		 (enjoy_LD3, offset(-0.2) msymbol(D) mlabposition(2)), ///
		 keep($keep) coeflabels($coeflabels , wrap(16) noticks labsize(small)) ///
		 headings(Dhousework_main ="{bf:QUANTITY OF TIME USE}" Dmultitasking_inc ="{bf:QUALITY OF TIME USE}", nogap) ///
		 xline(0, lpattern(dash) lcolor(gs12) lwidth(thin)) ///
		 mlabsize(small) mlabgap(*0.5) mfcolor(white) ///
		 xscale(range(-0.2 0.2)) xlabel(-0.2(0.1)0.2,format(%3.1f) labsize(small)) ///
		 mlabel(cond(@pval<.01, string(@b,"%9.2f")+"***", cond(@pval<.05, string(@b,"%9.2f")+"**", cond(@pval<.1, string(@b,"%9.2f")+"*", string(@b,"%9.2f"))))) ///
		 legend(order(2 "Lockdown 1 vs. Pre" 4 "Lockdown 3 vs. Pre") ///
		 position(12) ring(0) row(1) bplacement(n) symxsize(*0.5) size(small) region(lwidth(none)) bmargin(tiny)) ///
		 graphregion(color(white)) 

graph export "$output/Figure5.tif", as(tif) width(3000) replace

